#[macro_use] extern crate text_io;

pub mod mem;
pub mod byte;
pub mod exec;
pub mod io;
pub mod stack;
pub mod opcode;
pub mod math;

pub use mem::*;
pub use byte::*;
pub use exec::*;
pub use io::{*, Handle::*};
pub use stack::*;
pub use opcode::*;
pub use math::*;

#[cfg(test)]
mod tests;
